@@ -222,62 +222,68 @@ impl<Kind: DbKindT + Send + Sync + 'static> DbWrite<Kind> {
         sync_level: DbSyncLevel,
     ) -> DatabaseResult<Self> {
         DATABASE_HANDLES.get_or_insert(&kind, path_prefix, |kind| {
-            Self::new(path_prefix, kind, sync_level)
+            Self::new(Some(path_prefix), kind, sync_level)
         })
     }
 
     pub(crate) fn new(
-        path_prefix: &Path,
+        path_prefix: Option<&Path>,
         kind: Kind,
         sync_level: DbSyncLevel,
     ) -> DatabaseResult<Self> {
-        let path = path_prefix.join(kind.filename());
-        let parent = path
-            .parent()
-            .ok_or_else(|| DatabaseError::DatabaseMissing(path_prefix.to_owned()))?;
-        if !parent.is_dir() {
-            std::fs::create_dir_all(parent)
-                .map_err(|_e| DatabaseError::DatabaseMissing(parent.to_owned()))?;
-        }
-        // Check if the database is valid and take the appropriate
-        // action if it isn't.
-        match Connection::open(&path)
-            // For some reason calling pragma_update is necessary to prove the database file is valid.
-            .and_then(|mut c| {
-                crate::conn::initialize_connection(&mut c, sync_level)?;
-                c.pragma_update(None, "synchronous", &"0".to_string())
-            }) {
-            Ok(_) => (),
-            // These are the two errors that can
-            // occur if the database is not valid.
-            err @ Err(Error::SqliteFailure(
-                rusqlite::ffi::Error {
-                    code: ErrorCode::DatabaseCorrupt,
-                    ..
-                },
-                ..,
-            ))
-            | err @ Err(Error::SqliteFailure(
-                rusqlite::ffi::Error {
-                    code: ErrorCode::NotADatabase,
-                    ..
-                },
-                ..,
-            )) => {
-                // Check if this database kind requires wiping.
-                if kind.if_corrupt_wipe() {
-                    std::fs::remove_file(&path)?;
-                } else {
-                    // If we don't wipe we need to return an error.
-                    err?;
+        let path = match path_prefix {
+            Some(path_prefix) => {
+                let path = path_prefix.join(kind.filename());
+                let parent = path
+                    .parent()
+                    .ok_or_else(|| DatabaseError::DatabaseMissing(path_prefix.to_owned()))?;
+                if !parent.is_dir() {
+                    std::fs::create_dir_all(parent)
+                        .map_err(|_e| DatabaseError::DatabaseMissing(parent.to_owned()))?;
                 }
+                // Check if the database is valid and take the appropriate
+                // action if it isn't.
+                match Connection::open(&path)
+                    // For some reason calling pragma_update is necessary to prove the database file is valid.
+                    .and_then(|mut c| {
+                        crate::conn::initialize_connection(&mut c, sync_level)?;
+                        c.pragma_update(None, "synchronous", &"0".to_string())
+                    }) {
+                    Ok(_) => (),
+                    // These are the two errors that can
+                    // occur if the database is not valid.
+                    err @ Err(Error::SqliteFailure(
+                        rusqlite::ffi::Error {
+                            code: ErrorCode::DatabaseCorrupt,
+                            ..
+                        },
+                        ..,
+                    ))
+                    | err @ Err(Error::SqliteFailure(
+                        rusqlite::ffi::Error {
+                            code: ErrorCode::NotADatabase,
+                            ..
+                        },
+                        ..,
+                    )) => {
+                        // Check if this database kind requires wiping.
+                        if kind.if_corrupt_wipe() {
+                            std::fs::remove_file(&path)?;
+                        } else {
+                            // If we don't wipe we need to return an error.
+                            err?;
+                        }
+                    }
+                    // Another error has occurred when trying to open the db.
+                    Err(e) => return Err(e.into()),
+                }
+                Some(path)
             }
-            // Another error has occurred when trying to open the db.
-            Err(e) => return Err(e.into()),
-        }
+            None => None,
+        };
 
         // Now we know the database file is valid we can open a connection pool.
-        let pool = new_connection_pool(&path, sync_level);
+        let pool = new_connection_pool(path.as_ref().map(|p| p.as_ref()), sync_level);
         let mut conn = pool.get()?;
         // set to faster write-ahead-log mode
         conn.pragma_update(None, "journal_mode", &"WAL".to_string())?;
@@ -289,7 +295,7 @@ impl<Kind: DbKindT + Send + Sync + 'static> DbWrite<Kind> {
             max_readers: num_read_threads(),
             num_readers: Arc::new(AtomicUsize::new(0)),
             kind,
-            path,
+            path: path.unwrap_or_default(),
             connection_pool: pool,
         }))
     }
@@ -316,7 +322,12 @@ impl<Kind: DbKindT + Send + Sync + 'static> DbWrite<Kind> {
     /// connection pool, useful for testing.
     #[cfg(any(test, feature = "test_utils"))]
     pub fn test(tmpdir: &tempfile::TempDir, kind: Kind) -> DatabaseResult<Self> {
-        Self::new(tmpdir.path(), kind, DbSyncLevel::default())
+        Self::new(Some(tmpdir.path()), kind, DbSyncLevel::default())
+    }
+
+    #[cfg(any(test, feature = "test_utils"))]
+    pub fn test_in_mem(kind: Kind) -> DatabaseResult<Self> {
+        Self::new(None, kind, DbSyncLevel::default())
     }
 
     /// Remove the db and directory
@@ -342,6 +353,16 @@ impl<Kind: DbKindT + Send + Sync + 'static> DbWrite<Kind> {
         r
     }
 
+    #[cfg(any(test, feature = "test_utils"))]
+    pub fn test_commit<R, F>(&self, f: F) -> R
+    where
+        F: FnOnce(&mut Transaction) -> R,
+    {
+        let mut conn = self.conn().expect("Failed to open connection");
+        conn.with_commit_test(f)
+            .expect("Database transaction failed")
+    }
+
     /// If possible prefer async_commit as this is slower and can starve chained futures.
     pub async fn async_commit_in_place<E, R, F>(&self, f: F) -> Result<R, E>
     where
@@ -602,7 +623,7 @@ pub trait WriteManager<'e> {
     // /// which can properly recover from and manage write failures
     // fn writer_unmanaged(&'e mut self) -> DatabaseResult<Writer<'e>>;
 
-    #[cfg(feature = "test_utils")]
+    #[cfg(any(test, feature = "test_utils"))]
     fn with_commit_test<R, F>(&'e mut self, f: F) -> Result<R, DatabaseError>
     where
         F: 'e + FnOnce(&mut Transaction) -> R,
